@echo off
rem   demo 
rem 
rem   files created:
rem 
rem init.dat   original data (created by the user) boundary plus
rem             point in interior of bounded component of complement.
rem poly.dat   original data with extra points along polygonal boundary
rem poly.pre   preimage on the unit circle of poly.dat
rem orig.pre   preimage of init.dat
rem poly.par   parameters for the conformal map
rem poly.int   poly.pre plus intermediate points on unit circle
rem poly.img   image of poly.int by the conformal map
rem poly.grid  Carleson grid on disk
rem poly.gridi image of the Carleson grid in the region.
rem cgrid.dat  used to make Carleson grid
rem cgrid.img  used to make image of Carleson grid
rem grid.dat   grid of points in the region
rem grid.pre   preimage in the disk of grid.dat
rem sent.dsk   a curve in the disk
rem sent.img   a curve in the region
rem path.pts   data points for path (created by the user)
rem path.dat   path with extra points, after clipping
rem path.pre   preimage of path.dat in the disk.
rem error.est  estimate of supremum norm distance between two curves:
rem              the polygon with vertices init.dat and the computed
rem              image of the unit circle by the conformal map.
rem there are more files: this list needs to be updated.
rem 
rem 
copy /Y input\circle1 . >>logfile
copy /Y input\sent.dsk . >>logfile
echo *******************************************************
echo  This is a demonstration of some of the capabilities
echo  of the conformal mapping programs called ZIPPER.
echo  After trying it a few times, read the file demoPC.cmd and
echo  look at the input to the various fortran programs.
echo  You should then be able to design a version to suit
echo  your needs, with greater accuracy and speed.
echo *******************************************************
echo . 
echo .
echo .
pause
echo .
echo        Drag this window away from the upper right corner, so that
echo        it will be easier to see subsequent windows.
echo .
echo        * Toggles between points, lines, and both
echo .
echo        g Toggles between axes, background grid, fine grid and no grid
echo .
echo        zoom:  drag mb3 then click mb1 
echo .  
echo        percent: creates a postscript version of the plot called output.eps
echo .  
echo    After every picture, type q(uit) to continue
echo . 
pause
echo .  
rem   You can add an ampersand after any command below
rem    to keep the picture on the screen.  
rem  WARNING: If you do so, your
rem    speedy machine might continue to the next command before
rem    finishing  writing the output of a previous command
rem    causing errors.
echo . 
echo .
echo  IF THIS IS THE FIRST TIME YOU'VE TRIED THIS PROGRAM, 
echo  JUST HIT q, or any other key. The program will then use
echo  the default init.dat (cat picture from input\cat.g)
echo  Otherwise you will need a Jordan curve:
echo  an existing file consisting of a list of x,y 
echo  coordinates for the boundary points, followed by an interior pt.
echo  Copy or rename your file as init.dat, then restart the demo.
echo  For example use createdata.cmd to create init.dat with a mouse.
echo  See README.txt.
echo  If you have already done so, type q  (quit).
echo  .  
echo  To exit this program at any point type Ctrl-C, then q in grid
echo    window, then y (yes) in dos window.
echo .
echo .
pause
echo  Here is the initial data.
call plot init.dat
echo . 
echo . 
echo  Next we will put at least 200 points on the boundary of the
echo  polygon, with at least 5 points per edge.
rem  If your data is already  in the proper form for zipper, 
rem  (boundary data consists of an even number of points in counterclockwise
rem  order, and any bends must occur at odd numbered points - but not the
rem  at the first point-and at least 5 
rem  points between bends, and the boundary data is followed by the point to 
rem   be mapped to 0) 
rem   the program should then run 25 times faster without using polygon below.
rem   This is particularly useful if your boundary is smooth, or has
rem   only a few bends. It is more accurate if the spacing of points
rem   is roughly like arc length.

zipper\polygon < input\polygon.inp >logfile

echo . 
echo   Here is the data with added boundary points, 
echo   followed by the interior point
echo   Hit * to toggle between points, lines, and both.
echo *******************************************************
echo   Remember to click on Quit to continue
echo *******************************************************

call plot poly.dat init.dat

echo . 
echo . 
echo  Now we will compute the conformal map to the disk

zipper\zipper

rem  If zipper crashes, or if the distance from the data (poly.dat)
rem  to the computed curve (poly.img) is too great, increase
rem  the number of points in poly.dat by increasing 200 in polygon.inp.

rem next we list the preimages of the original data points.
zipper\origpre

echo . 
echo . 
echo  Here are the preimages of the original data on the unit circle
echo  connected by straight lines (blue),
echo  along with the preimages of the additional boundary points(red).
echo  Notice the compression\expansion of the points.

echo *******************************************************
echo   Remember to click on Quit to continue
echo *******************************************************

call plot poly.pre orig.pre

echo . 
echo . 
rem if (! -e cgrid.dat ) then
   echo  Now we will generate a Carleson grid on the disk
   echo  Toggle * to see the points or points and lines

   zipper\cgrids<input\cgrids.inp >>logfile
   zipper\corders<input\corders.inp1 >>logfile
   echo .  
rem else 
rem   echo  Here is a Carleson grid on the disk
rem endif
echo *******************************************************
echo   Remember to click on Quit to continue
echo *******************************************************

call plot -l poly.grid circle1

echo .  
echo  Now we will compute the image of the unit circle at
echo  4 times the number of data points (at the preimages of the
echo  vertices on the circle and at three points between each
echo  preimage of a vertex)
echo  Then we will compute the image of the Carleson grid
echo  (At least 2000 points)

zipper\forward < input\forward.inp1 >>logfile

echo .  
echo *******************************************************
echo  Estimate of the relative (supremum norm) error:
type error.est
echo  This error can be decreased by increasing 200 in polygon.inp
echo *******************************************************
echo .  
rem  Here we reorder the points on the grid for plotting
zipper\corders<input\corders.inp2 >>logfile
pause
echo .  


echo  Here is the image of the Carleson grid(red), the image of the unit
echo  circle(green), and the original data(blue), connected by straight lines
echo .   
echo   toggle * to see the image of the data points.
echo     Zoom: right click and drag then left click (clicks on corner of
echo        a rectangle) 
echo        zoom until you can see the difference between the
echo     curve formed by straight line segments between the data points
echo     (green) and the image of the circle(blue). Typing p or n 
echo      will go to previous or next after zooming
echo     Try also typing "g" to toggle the grid
echo     By counting boxes you can estimate the harmonic measure of
echo     an interval on the boundary of the region.
echo .  
echo .  

echo *******************************************************
call plot -l poly.gridi poly.img poly.dat


echo .  
echo  For the next example, we first select a (square) grid of
echo  points inside the region. 

zipper\imagegr<input\imagegr.inp >>logfile

echo .   

echo *******************************************************
call plot -p poly.dat grid.dat

echo .  
echo  Now we will find the (pre)images of the grid points in the disk

zipper\inverse<input\inverse.inp1 >>logfile

echo .    
echo .    
echo  You might need to zoom to distinquish some of the points.
echo  Note that the image is locally square.
echo .    
echo .    

echo *******************************************************
call plot -p circle1 grid.pre

echo .  
echo .  
echo *******************************************************
echo  This numerical routine is useful in theoretical experimentation
echo  because not only does it give an approximation to a desired
echo  conformal map, but the map it computes is conformal itself,
echo  even very near the boundary.
echo  To see this, first try to read the next sentence
echo  by zooming: right click then drag and then left click 
echo  to form a rectangle. 
echo  Repeat this several times.
echo .    
echo *******************************************************
call plot -l sent.dsk circle1

echo .  
echo  Now we will map the sentence to the region. Notice that the
echo  image of the sentence can still be read, since the map is
echo  conformal. Look at the numbers on the axes to see how close
echo  the points really are.
echo .   
echo *******************************************************
zipper\forward< input\forward.inp5 >>logfile
call plot -l sent.img poly.img

echo .  
echo .   
echo  Another way to visualize the compression\expansion of the
echo  conformal map is to compute the image of equally spaced points
echo  on the unit circle. Here is the image of 1024 equally spaced
echo  points on the unit circle.
echo .    
echo . 
echo .   
echo  Toggle * to see the points.
echo  These points may not be precisely on the green boundary,
echo  because the image of the circle is not precisely the boundary
echo  of the region. You can see how close they are by zooming in a
echo  few times (see error estimate above).
echo  If you toggle *,
echo  you will see the image of 0 and the original data.
zipper\circle<input\circle.inp>>logfile
zipper\forward < input\forward.inp6 >>logfile

call plot poly.dat fftpts.img 

echo .

echo .
echo  Next we will use the geodesic version of the algorithm
echo  to find the conformal maps from to the inside and outside
echo  of the region. Here is a Carleson grid inside the disk and a
echo  Carleson grid outside the disk. 
echo .
zipper\corders < input\corders.inp5>>logfile

call plot -l poly.grid poly.grido poly.pre

echo .
echo  Next we will find the images of these grids by the two maps.
echo  NOTE: the geodesic version is really designed for smooth (C^1)
echo       curves. It creates a smooth Jordan curve
echo       through the data points.  For this demo, additional points 
echo       are added along straight lines between the data points
echo       in init.dat. Then the original data points are be removed. 
echo       This has the effect of rounding the corners if init.dat 
echo       are not very smooth or if too few boundary points are given.
echo   WARNING: a point in each component of the complement of the 
echo       given boundary curve is needed to do welding, the point
echo       infinity is chosen for the unbounded component. This means
echo       that the interior point in the input file init.dat needs
echo       to be in the bounded component. This was done for the
echo       convenience of the user.  The code can be changed to 
echo       allow an arbitrary choice of points, if desired.
echo .
echo       Use the zipper program instead, if you want corners (as was
echo       done in the beginning of this demo).
echo .

geodesic\geopoly < input\geopoly.inp >>logfile
geodesic\geounweld < input\geounweld.inp1 >>logfile
copy /Y cgrid.dat zplanepts.ga  >>logfile
geodesic\geofor >>logfile
zipper\corders < input\corders.inp3 >>logfile
copy /Y cgrido.dat zplanepts.ga >>logfile
geodesic\geofor>>logfile
zipper\corders < input\corders.inp4>>logfile
call plot -l interior.ga exterior.ga bdata.ga


echo .
echo  Composing one map with the inverse of the
echo  other will give the welding homeomorphism of the circle.
echo  Here is the welding graphed as a map
echo  of the interval [0,2\pi] to itself.
echo .
call plot -l welding.ga

echo .
echo .
echo .
echo  A homotopy of the welding to the identity welding
echo  is computed (project with slope -1, with 20 steps)
echo  then for each of these 20 welding maps, the corresponding
echo  conformal map is constructed. The collection of boundaries
echo  are then plotted.
echo . 
geodesic\geoweld<input\geoweld.inp1>>logfile
call plot -l homotopy.ga
call plot -l curve.ga
echo .   
echo *******************************************************
echo .   
echo .   
echo  If you want to view again any of the preceeding pictures,
echo  or look at the data files directly, read the file demoPC.
echo .   
echo    The accuracy of the numerical routine can be measured by
echo    looking at the difference between the curves poly.dat and
echo    poly.img for the zipper program. For the geodesic program
echo    compare bdata.ga and cbndry.ga  
echo    To increase the accuracy, change the 200 in
echo    polygon.inp to a higher number.  It will increase the running
echo    time. To evaluate the map at more points on the unit
echo    circle, increase the 4 in forward.inp1. 
echo .   
echo .   
echo  After you've tried this program, you can then try to create your own
echo  Jordan curve by clicking on
echo  C:\Program Files\createdata.cmd
echo .  
echo  a window will pop up and you can click on points. Type q when done. A
echo  second window will pop up for you to enter an interior point.
echo .  
echo  If you mess up and need to adjust some of the points, click on:
echo  C:\Program Files\editdata.cmd
echo .  
echo  The result will be put into the file init.dat
echo .  
echo  If you want to go back to the original example then 
echo  copy cat.dat init.dat
echo .  
echo  Or you can try 
echo  copy sno2.dat init.dat

echo .  
echo  Or you can create init.dat in other ways. Just be sure that the last
echo  point is an interior point.


echo  Please send bug reports, comments and suggestions to
echo  marshall@math.washington.edu
echo .  
echo .  
echo  I would appreciate hearing what you used this program for.
echo *******************************************************
echo . 
pause
echo . 
